=== modified file 'snapcraft/tests/test_yaml.py'
--- snapcraft/tests/test_yaml.py	2015-09-29 13:36:43 +0000
+++ snapcraft/tests/test_yaml.py	2015-09-30 20:28:59 +0000
@@ -198,6 +198,28 @@
         self.assertEqual(raised.exception.message, '\'myapp@me_1.0\' does not match \'^[a-z0-9][a-z0-9+-]*$\'')
 
     @unittest.mock.patch('snapcraft.yaml.Config.load_plugin')
+    def test_deprecation_for_type(self, mock_loadPlugin):
+        fake_logger = fixtures.FakeLogger(level=logging.WARNING)
+        self.useFixture(fake_logger)
+
+        self.make_snapcraft_yaml("""name: myapp
+version: "1"
+vendor: me <me@me.com>
+summary: test
+description: nothing
+icon: my-icon.png
+
+parts:
+  part1:
+    type: go
+    stage-packages: [fswebcam]
+""")
+        config = snapcraft.yaml.Config()
+        self.assertEqual(fake_logger.output,
+                         'DEPRECATED: Use "plugin" instead of "type"\n')
+        self.assertFalse('type' in config.data)
+
+    @unittest.mock.patch('snapcraft.yaml.Config.load_plugin')
     def test_invalid_yaml_missing_description(self, mock_loadPlugin):
         fake_logger = fixtures.FakeLogger(level=logging.ERROR)
         self.useFixture(fake_logger)

=== modified file 'snapcraft/yaml.py'
--- snapcraft/yaml.py	2015-09-30 19:44:28 +0000
+++ snapcraft/yaml.py	2015-09-30 20:28:59 +0000
@@ -86,6 +86,10 @@
 
             plugin_name = properties.pop("plugin", None)
             # TODO search the wiki
+            if not plugin_name and 'type' in properties:
+                plugin_name = properties.pop('type')
+                logger.warning('DEPRECATED: Use "plugin" instead of "type"')
+
             if not plugin_name:
                 raise PluginNotDefinedError
 

